{# Hidden input elements used to maintain the component's state #}
{# and used when submitting forms #}
{% for value in values %}
        <input type="hidden" name="{{ name }}" value="{{ value }}" />
{% endfor %}
{% if required and values|length == 0 %}
<input type="text" name="{{ name }}" required class="ac_required_input">
{% endif %}